@@ -1,7 +1,7 @@
 """
 Type annotations for datapipeline service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/type_defs/)
 
 Usage::
 
@@ -79,14 +79,27 @@ __all__ = (
     "ValidationWarningTypeDef",
 )
 
-ActivatePipelineInputRequestTypeDef = TypedDict(
-    "ActivatePipelineInputRequestTypeDef",
+_RequiredActivatePipelineInputRequestTypeDef = TypedDict(
+    "_RequiredActivatePipelineInputRequestTypeDef",
     {
         "pipelineId": str,
-        "parameterValues": NotRequired[Sequence["ParameterValueTypeDef"]],
-        "startTimestamp": NotRequired[Union[datetime, str]],
     },
 )
+_OptionalActivatePipelineInputRequestTypeDef = TypedDict(
+    "_OptionalActivatePipelineInputRequestTypeDef",
+    {
+        "parameterValues": Sequence["ParameterValueTypeDef"],
+        "startTimestamp": Union[datetime, str],
+    },
+    total=False,
+)
+
+
+class ActivatePipelineInputRequestTypeDef(
+    _RequiredActivatePipelineInputRequestTypeDef, _OptionalActivatePipelineInputRequestTypeDef
+):
+    pass
+
 
 AddTagsInputRequestTypeDef = TypedDict(
     "AddTagsInputRequestTypeDef",
@@ -96,15 +109,28 @@ AddTagsInputRequestTypeDef = TypedDict(
     },
 )
 
-CreatePipelineInputRequestTypeDef = TypedDict(
-    "CreatePipelineInputRequestTypeDef",
+_RequiredCreatePipelineInputRequestTypeDef = TypedDict(
+    "_RequiredCreatePipelineInputRequestTypeDef",
     {
         "name": str,
         "uniqueId": str,
-        "description": NotRequired[str],
-        "tags": NotRequired[Sequence["TagTypeDef"]],
     },
 )
+_OptionalCreatePipelineInputRequestTypeDef = TypedDict(
+    "_OptionalCreatePipelineInputRequestTypeDef",
+    {
+        "description": str,
+        "tags": Sequence["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreatePipelineInputRequestTypeDef(
+    _RequiredCreatePipelineInputRequestTypeDef, _OptionalCreatePipelineInputRequestTypeDef
+):
+    pass
+
 
 CreatePipelineOutputTypeDef = TypedDict(
     "CreatePipelineOutputTypeDef",
@@ -114,13 +140,26 @@ CreatePipelineOutputTypeDef = TypedDict(
     },
 )
 
-DeactivatePipelineInputRequestTypeDef = TypedDict(
-    "DeactivatePipelineInputRequestTypeDef",
+_RequiredDeactivatePipelineInputRequestTypeDef = TypedDict(
+    "_RequiredDeactivatePipelineInputRequestTypeDef",
     {
         "pipelineId": str,
-        "cancelActive": NotRequired[bool],
     },
 )
+_OptionalDeactivatePipelineInputRequestTypeDef = TypedDict(
+    "_OptionalDeactivatePipelineInputRequestTypeDef",
+    {
+        "cancelActive": bool,
+    },
+    total=False,
+)
+
+
+class DeactivatePipelineInputRequestTypeDef(
+    _RequiredDeactivatePipelineInputRequestTypeDef, _OptionalDeactivatePipelineInputRequestTypeDef
+):
+    pass
+
 
 DeletePipelineInputRequestTypeDef = TypedDict(
     "DeletePipelineInputRequestTypeDef",
@@ -129,25 +168,52 @@ DeletePipelineInputRequestTypeDef = TypedDict(
     },
 )
 
-DescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
-    "DescribeObjectsInputDescribeObjectsPaginateTypeDef",
+_RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
+    "_RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef",
     {
         "pipelineId": str,
         "objectIds": Sequence[str],
-        "evaluateExpressions": NotRequired[bool],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
+    "_OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef",
+    {
+        "evaluateExpressions": bool,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-DescribeObjectsInputRequestTypeDef = TypedDict(
-    "DescribeObjectsInputRequestTypeDef",
+
+class DescribeObjectsInputDescribeObjectsPaginateTypeDef(
+    _RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef,
+    _OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredDescribeObjectsInputRequestTypeDef = TypedDict(
+    "_RequiredDescribeObjectsInputRequestTypeDef",
     {
         "pipelineId": str,
         "objectIds": Sequence[str],
-        "evaluateExpressions": NotRequired[bool],
-        "marker": NotRequired[str],
     },
 )
+_OptionalDescribeObjectsInputRequestTypeDef = TypedDict(
+    "_OptionalDescribeObjectsInputRequestTypeDef",
+    {
+        "evaluateExpressions": bool,
+        "marker": str,
+    },
+    total=False,
+)
+
+
+class DescribeObjectsInputRequestTypeDef(
+    _RequiredDescribeObjectsInputRequestTypeDef, _OptionalDescribeObjectsInputRequestTypeDef
+):
+    pass
+
 
 DescribeObjectsOutputTypeDef = TypedDict(
     "DescribeObjectsOutputTypeDef",
@@ -191,22 +257,47 @@ EvaluateExpressionOutputTypeDef = TypedDict(
     },
 )
 
-FieldTypeDef = TypedDict(
-    "FieldTypeDef",
+_RequiredFieldTypeDef = TypedDict(
+    "_RequiredFieldTypeDef",
     {
         "key": str,
-        "stringValue": NotRequired[str],
-        "refValue": NotRequired[str],
     },
 )
+_OptionalFieldTypeDef = TypedDict(
+    "_OptionalFieldTypeDef",
+    {
+        "stringValue": str,
+        "refValue": str,
+    },
+    total=False,
+)
 
-GetPipelineDefinitionInputRequestTypeDef = TypedDict(
-    "GetPipelineDefinitionInputRequestTypeDef",
+
+class FieldTypeDef(_RequiredFieldTypeDef, _OptionalFieldTypeDef):
+    pass
+
+
+_RequiredGetPipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_RequiredGetPipelineDefinitionInputRequestTypeDef",
     {
         "pipelineId": str,
-        "version": NotRequired[str],
     },
 )
+_OptionalGetPipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_OptionalGetPipelineDefinitionInputRequestTypeDef",
+    {
+        "version": str,
+    },
+    total=False,
+)
+
+
+class GetPipelineDefinitionInputRequestTypeDef(
+    _RequiredGetPipelineDefinitionInputRequestTypeDef,
+    _OptionalGetPipelineDefinitionInputRequestTypeDef,
+):
+    pass
+
 
 GetPipelineDefinitionOutputTypeDef = TypedDict(
     "GetPipelineDefinitionOutputTypeDef",
@@ -221,23 +312,26 @@ GetPipelineDefinitionOutputTypeDef = TypedDict(
 InstanceIdentityTypeDef = TypedDict(
     "InstanceIdentityTypeDef",
     {
-        "document": NotRequired[str],
-        "signature": NotRequired[str],
+        "document": str,
+        "signature": str,
     },
+    total=False,
 )
 
 ListPipelinesInputListPipelinesPaginateTypeDef = TypedDict(
     "ListPipelinesInputListPipelinesPaginateTypeDef",
     {
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
     },
+    total=False,
 )
 
 ListPipelinesInputRequestTypeDef = TypedDict(
     "ListPipelinesInputRequestTypeDef",
     {
-        "marker": NotRequired[str],
+        "marker": str,
     },
+    total=False,
 )
 
 ListPipelinesOutputTypeDef = TypedDict(
@@ -253,18 +347,20 @@ ListPipelinesOutputTypeDef = TypedDict(
 OperatorTypeDef = TypedDict(
     "OperatorTypeDef",
     {
-        "type": NotRequired[OperatorTypeType],
-        "values": NotRequired[Sequence[str]],
+        "type": OperatorTypeType,
+        "values": Sequence[str],
     },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 ParameterAttributeTypeDef = TypedDict(
@@ -291,23 +387,37 @@ ParameterValueTypeDef = TypedDict(
     },
 )
 
-PipelineDescriptionTypeDef = TypedDict(
-    "PipelineDescriptionTypeDef",
+_RequiredPipelineDescriptionTypeDef = TypedDict(
+    "_RequiredPipelineDescriptionTypeDef",
     {
         "pipelineId": str,
         "name": str,
         "fields": List["FieldTypeDef"],
-        "description": NotRequired[str],
-        "tags": NotRequired[List["TagTypeDef"]],
     },
 )
+_OptionalPipelineDescriptionTypeDef = TypedDict(
+    "_OptionalPipelineDescriptionTypeDef",
+    {
+        "description": str,
+        "tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class PipelineDescriptionTypeDef(
+    _RequiredPipelineDescriptionTypeDef, _OptionalPipelineDescriptionTypeDef
+):
+    pass
+
 
 PipelineIdNameTypeDef = TypedDict(
     "PipelineIdNameTypeDef",
     {
-        "id": NotRequired[str],
-        "name": NotRequired[str],
+        "id": str,
+        "name": str,
     },
+    total=False,
 )
 
 PipelineObjectTypeDef = TypedDict(
@@ -319,14 +429,27 @@ PipelineObjectTypeDef = TypedDict(
     },
 )
 
-PollForTaskInputRequestTypeDef = TypedDict(
-    "PollForTaskInputRequestTypeDef",
+_RequiredPollForTaskInputRequestTypeDef = TypedDict(
+    "_RequiredPollForTaskInputRequestTypeDef",
     {
         "workerGroup": str,
-        "hostname": NotRequired[str],
-        "instanceIdentity": NotRequired["InstanceIdentityTypeDef"],
     },
 )
+_OptionalPollForTaskInputRequestTypeDef = TypedDict(
+    "_OptionalPollForTaskInputRequestTypeDef",
+    {
+        "hostname": str,
+        "instanceIdentity": "InstanceIdentityTypeDef",
+    },
+    total=False,
+)
+
+
+class PollForTaskInputRequestTypeDef(
+    _RequiredPollForTaskInputRequestTypeDef, _OptionalPollForTaskInputRequestTypeDef
+):
+    pass
+
 
 PollForTaskOutputTypeDef = TypedDict(
     "PollForTaskOutputTypeDef",
@@ -336,15 +459,29 @@ PollForTaskOutputTypeDef = TypedDict(
     },
 )
 
-PutPipelineDefinitionInputRequestTypeDef = TypedDict(
-    "PutPipelineDefinitionInputRequestTypeDef",
+_RequiredPutPipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_RequiredPutPipelineDefinitionInputRequestTypeDef",
     {
         "pipelineId": str,
         "pipelineObjects": Sequence["PipelineObjectTypeDef"],
-        "parameterObjects": NotRequired[Sequence["ParameterObjectTypeDef"]],
-        "parameterValues": NotRequired[Sequence["ParameterValueTypeDef"]],
     },
 )
+_OptionalPutPipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_OptionalPutPipelineDefinitionInputRequestTypeDef",
+    {
+        "parameterObjects": Sequence["ParameterObjectTypeDef"],
+        "parameterValues": Sequence["ParameterValueTypeDef"],
+    },
+    total=False,
+)
+
+
+class PutPipelineDefinitionInputRequestTypeDef(
+    _RequiredPutPipelineDefinitionInputRequestTypeDef,
+    _OptionalPutPipelineDefinitionInputRequestTypeDef,
+):
+    pass
+
 
 PutPipelineDefinitionOutputTypeDef = TypedDict(
     "PutPipelineDefinitionOutputTypeDef",
@@ -356,26 +493,53 @@ PutPipelineDefinitionOutputTypeDef = TypedDict(
     },
 )
 
-QueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
-    "QueryObjectsInputQueryObjectsPaginateTypeDef",
+_RequiredQueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
+    "_RequiredQueryObjectsInputQueryObjectsPaginateTypeDef",
     {
         "pipelineId": str,
         "sphere": str,
-        "query": NotRequired["QueryTypeDef"],
-        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
     },
 )
+_OptionalQueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
+    "_OptionalQueryObjectsInputQueryObjectsPaginateTypeDef",
+    {
+        "query": "QueryTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
 
-QueryObjectsInputRequestTypeDef = TypedDict(
-    "QueryObjectsInputRequestTypeDef",
+
+class QueryObjectsInputQueryObjectsPaginateTypeDef(
+    _RequiredQueryObjectsInputQueryObjectsPaginateTypeDef,
+    _OptionalQueryObjectsInputQueryObjectsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredQueryObjectsInputRequestTypeDef = TypedDict(
+    "_RequiredQueryObjectsInputRequestTypeDef",
     {
         "pipelineId": str,
         "sphere": str,
-        "query": NotRequired["QueryTypeDef"],
-        "marker": NotRequired[str],
-        "limit": NotRequired[int],
     },
 )
+_OptionalQueryObjectsInputRequestTypeDef = TypedDict(
+    "_OptionalQueryObjectsInputRequestTypeDef",
+    {
+        "query": "QueryTypeDef",
+        "marker": str,
+        "limit": int,
+    },
+    total=False,
+)
+
+
+class QueryObjectsInputRequestTypeDef(
+    _RequiredQueryObjectsInputRequestTypeDef, _OptionalQueryObjectsInputRequestTypeDef
+):
+    pass
+
 
 QueryObjectsOutputTypeDef = TypedDict(
     "QueryObjectsOutputTypeDef",
@@ -390,8 +554,9 @@ QueryObjectsOutputTypeDef = TypedDict(
 QueryTypeDef = TypedDict(
     "QueryTypeDef",
     {
-        "selectors": NotRequired[Sequence["SelectorTypeDef"]],
+        "selectors": Sequence["SelectorTypeDef"],
     },
+    total=False,
 )
 
 RemoveTagsInputRequestTypeDef = TypedDict(
@@ -402,13 +567,26 @@ RemoveTagsInputRequestTypeDef = TypedDict(
     },
 )
 
-ReportTaskProgressInputRequestTypeDef = TypedDict(
-    "ReportTaskProgressInputRequestTypeDef",
+_RequiredReportTaskProgressInputRequestTypeDef = TypedDict(
+    "_RequiredReportTaskProgressInputRequestTypeDef",
     {
         "taskId": str,
-        "fields": NotRequired[Sequence["FieldTypeDef"]],
     },
 )
+_OptionalReportTaskProgressInputRequestTypeDef = TypedDict(
+    "_OptionalReportTaskProgressInputRequestTypeDef",
+    {
+        "fields": Sequence["FieldTypeDef"],
+    },
+    total=False,
+)
+
+
+class ReportTaskProgressInputRequestTypeDef(
+    _RequiredReportTaskProgressInputRequestTypeDef, _OptionalReportTaskProgressInputRequestTypeDef
+):
+    pass
+
 
 ReportTaskProgressOutputTypeDef = TypedDict(
     "ReportTaskProgressOutputTypeDef",
@@ -418,14 +596,28 @@ ReportTaskProgressOutputTypeDef = TypedDict(
     },
 )
 
-ReportTaskRunnerHeartbeatInputRequestTypeDef = TypedDict(
-    "ReportTaskRunnerHeartbeatInputRequestTypeDef",
+_RequiredReportTaskRunnerHeartbeatInputRequestTypeDef = TypedDict(
+    "_RequiredReportTaskRunnerHeartbeatInputRequestTypeDef",
     {
         "taskrunnerId": str,
-        "workerGroup": NotRequired[str],
-        "hostname": NotRequired[str],
     },
 )
+_OptionalReportTaskRunnerHeartbeatInputRequestTypeDef = TypedDict(
+    "_OptionalReportTaskRunnerHeartbeatInputRequestTypeDef",
+    {
+        "workerGroup": str,
+        "hostname": str,
+    },
+    total=False,
+)
+
+
+class ReportTaskRunnerHeartbeatInputRequestTypeDef(
+    _RequiredReportTaskRunnerHeartbeatInputRequestTypeDef,
+    _OptionalReportTaskRunnerHeartbeatInputRequestTypeDef,
+):
+    pass
+
 
 ReportTaskRunnerHeartbeatOutputTypeDef = TypedDict(
     "ReportTaskRunnerHeartbeatOutputTypeDef",
@@ -449,9 +641,10 @@ ResponseMetadataTypeDef = TypedDict(
 SelectorTypeDef = TypedDict(
     "SelectorTypeDef",
     {
-        "fieldName": NotRequired[str],
-        "operator": NotRequired["OperatorTypeDef"],
+        "fieldName": str,
+        "operator": "OperatorTypeDef",
     },
+    total=False,
 )
 
 SetStatusInputRequestTypeDef = TypedDict(
@@ -463,16 +656,29 @@ SetStatusInputRequestTypeDef = TypedDict(
     },
 )
 
-SetTaskStatusInputRequestTypeDef = TypedDict(
-    "SetTaskStatusInputRequestTypeDef",
+_RequiredSetTaskStatusInputRequestTypeDef = TypedDict(
+    "_RequiredSetTaskStatusInputRequestTypeDef",
     {
         "taskId": str,
         "taskStatus": TaskStatusType,
-        "errorId": NotRequired[str],
-        "errorMessage": NotRequired[str],
-        "errorStackTrace": NotRequired[str],
     },
 )
+_OptionalSetTaskStatusInputRequestTypeDef = TypedDict(
+    "_OptionalSetTaskStatusInputRequestTypeDef",
+    {
+        "errorId": str,
+        "errorMessage": str,
+        "errorStackTrace": str,
+    },
+    total=False,
+)
+
+
+class SetTaskStatusInputRequestTypeDef(
+    _RequiredSetTaskStatusInputRequestTypeDef, _OptionalSetTaskStatusInputRequestTypeDef
+):
+    pass
+
 
 TagTypeDef = TypedDict(
     "TagTypeDef",
@@ -485,22 +691,37 @@ TagTypeDef = TypedDict(
 TaskObjectTypeDef = TypedDict(
     "TaskObjectTypeDef",
     {
-        "taskId": NotRequired[str],
-        "pipelineId": NotRequired[str],
-        "attemptId": NotRequired[str],
-        "objects": NotRequired[Dict[str, "PipelineObjectTypeDef"]],
+        "taskId": str,
+        "pipelineId": str,
+        "attemptId": str,
+        "objects": Dict[str, "PipelineObjectTypeDef"],
     },
+    total=False,
 )
 
-ValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
-    "ValidatePipelineDefinitionInputRequestTypeDef",
+_RequiredValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_RequiredValidatePipelineDefinitionInputRequestTypeDef",
     {
         "pipelineId": str,
         "pipelineObjects": Sequence["PipelineObjectTypeDef"],
-        "parameterObjects": NotRequired[Sequence["ParameterObjectTypeDef"]],
-        "parameterValues": NotRequired[Sequence["ParameterValueTypeDef"]],
     },
 )
+_OptionalValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_OptionalValidatePipelineDefinitionInputRequestTypeDef",
+    {
+        "parameterObjects": Sequence["ParameterObjectTypeDef"],
+        "parameterValues": Sequence["ParameterValueTypeDef"],
+    },
+    total=False,
+)
+
+
+class ValidatePipelineDefinitionInputRequestTypeDef(
+    _RequiredValidatePipelineDefinitionInputRequestTypeDef,
+    _OptionalValidatePipelineDefinitionInputRequestTypeDef,
+):
+    pass
+
 
 ValidatePipelineDefinitionOutputTypeDef = TypedDict(
     "ValidatePipelineDefinitionOutputTypeDef",
@@ -515,15 +736,17 @@ ValidatePipelineDefinitionOutputTypeDef = TypedDict(
 ValidationErrorTypeDef = TypedDict(
     "ValidationErrorTypeDef",
     {
-        "id": NotRequired[str],
-        "errors": NotRequired[List[str]],
+        "id": str,
+        "errors": List[str],
     },
+    total=False,
 )
 
 ValidationWarningTypeDef = TypedDict(
     "ValidationWarningTypeDef",
     {
-        "id": NotRequired[str],
-        "warnings": NotRequired[List[str]],
+        "id": str,
+        "warnings": List[str],
     },
+    total=False,
 )
